"use client"

import { useState } from 'react'
import { useRouter } from 'next/navigation'
import { motion } from 'framer-motion'
import { User, BookOpen, Calendar, Clock } from 'lucide-react'
import { Card, CardContent, CardDescription, CardFooter, CardHeader, CardTitle } from '@/components/ui/card'
import { Button } from '@/components/ui/button'
import { formatDate, formatTime } from '@/lib/utils'

interface Slot {
  id: string
  date: Date
  time: string
  isAvailable: boolean
}

interface TeacherCardProps {
  id: string
  name: string
  subject: string
  slots: Slot[]
}

export default function TeacherCard({ id, name, subject, slots }: TeacherCardProps) {
  const [isExpanded, setIsExpanded] = useState(false)
  const router = useRouter()
  
  // Group slots by date
  const slotsByDate = slots.reduce((acc, slot) => {
    const dateStr = new Date(slot.date).toDateString()
    if (!acc[dateStr]) {
      acc[dateStr] = []
    }
    acc[dateStr].push(slot)
    return acc
  }, {} as Record<string, Slot[]>)
  
  // Sort slots by time for each date
  Object.keys(slotsByDate).forEach(date => {
    slotsByDate[date].sort((a, b) => {
      return a.time.localeCompare(b.time)
    })
  })
  
  const handleBookSlot = (slotId: string) => {
    router.push(`/book/${slotId}`)
  }

  return (
    <motion.div
      initial={{ opacity: 0, y: 20 }}
      animate={{ opacity: 1, y: 0 }}
      whileHover={{ y: -5 }}
      transition={{ duration: 0.3 }}
    >
      <Card className="h-full">
        <CardHeader>
          <CardTitle className="flex items-center">
            <User className="h-5 w-5 mr-2 text-primary" />
            {name}
          </CardTitle>
          <CardDescription className="flex items-center">
            <BookOpen className="h-4 w-4 mr-2 text-muted-foreground" />
            {subject}
          </CardDescription>
        </CardHeader>
        <CardContent>
          <div className="text-sm mb-2 flex items-center">
            <Calendar className="h-4 w-4 mr-2 text-primary" />
            <span>{slots.length} available time slots</span>
          </div>
          
          {isExpanded && (
            <motion.div 
              className="space-y-4 mt-4"
              initial={{ opacity: 0, height: 0 }}
              animate={{ opacity: 1, height: 'auto' }}
              transition={{ duration: 0.3 }}
            >
              {Object.keys(slotsByDate).map(dateStr => (
                <div key={dateStr} className="space-y-2">
                  <h4 className="font-medium text-sm">{formatDate(new Date(dateStr))}</h4>
                  <div className="grid grid-cols-2 gap-2">
                    {slotsByDate[dateStr].map(slot => (
                      <Button
                        key={slot.id}
                        variant="outline"
                        size="sm"
                        className="flex items-center justify-center"
                        onClick={() => handleBookSlot(slot.id)}
                      >
                        <Clock className="h-3 w-3 mr-1" />
                        {formatTime(slot.time)}
                      </Button>
                    ))}
                  </div>
                </div>
              ))}
            </motion.div>
          )}
        </CardContent>
        <CardFooter>
          <Button 
            variant="secondary" 
            className="w-full"
            onClick={() => setIsExpanded(!isExpanded)}
          >
            {isExpanded ? 'Hide Slots' : 'View Available Slots'}
          </Button>
        </CardFooter>
      </Card>
    </motion.div>
  )
}